cross

Function cross 

pub fn cross<T: From<i8>>() -> StaticMatrix<T, 9>
A laplacian filter that works in a cross, ignoring data from the diagonals

This function is generic so that you can choose the data type that works best for you.

Example

let mat = kernel::laplacian::cross::<i8>();
let kernel = [
     0, -1,  0,
    -1,  4, -1,
     0, -1,  0,
];
 
assert_eq!(mat.into_parts().2, kernel);